@@ -135,7 +135,7 @@ class SOMEIPDatagramProtocol:
         if not remote:
             remote = self.default_addr
         # workaround for https://github.com/python/typeshed/pull/3943
-        self.transport.sendto(buf, remote)  # type: ignore[arg-type]
+        self.transport.sendto(buf, remote)
 
 
 class DatagramProtocolAdapter(asyncio.DatagramProtocol):
@@ -271,7 +271,7 @@ class ServiceDiscoveryProtocol(SOMEIPDatagramProtocol):
 
             if (
                 family == socket.AF_INET6
-                and platform.python_version_tuple() < (3, 8, 4)
+                and platform.python_version_tuple() < ('3', '8', '4')
                 and isinstance(loop, getattr(asyncio, "ProactorEventLoop", ()))
             ):
                 prot.log.warning(
